****************************************************************************************************
*Replication Do-File - Hurka/Haag: Policy complexity and legislative duration in the European Union*
*																								   *	
*EUROPEAN UNION POLITICS                                                                           *
****************************************************************************************************


* Please make sure you have the following commands installed before running the do-file:

* scurve_tvc
* blindschemes



* Load data

cd "INSERT DIRECTORY HERE"

log using Hurka_Haag_EUP, replace

use "Policy complexity replication.dta", clear



* Tell STATA we are dealing with survival data

stset tdays, id(id) failure(tstatus==1)


**********
*Analysis*
**********


* Table 1. Cox proportional hazards regression with time-varying coefficients
* See Grambsch-Therneau test in Table B (online appendix) for violations of PH assumption

set more off

stcox p_size_s p_wen_s p_ref_art_s directive decision codification recast ///
amending council_lr council_eu days_left proposal_backlog ///
econ envi imco inta itre libe, tvc(p_size_s p_wen_s directive council_eu) texp(ln(_t))

outreg2 using "Table1", label bdec(3) eform word replace


* Figure 1. Survival functions: structural policy complexity

set more off

scurve_tvc, generate (s1) at(p_size_s -0.7 p_wen_s 0 p_ref_art_s 0 directive 1 decision 0 codification 0 recast 0 ///
amending 0 council_lr 13.02 council_eu 2.63 days_left 74.91 proposal_backlog 253.73 ///
econ 0 envi 0 imco 0 inta 0 itre 0 libe 0) tvc(p_size_s p_wen_s directive council_eu) ///
texp(ln(_t))


scurve_tvc, generate (s2) at(p_size_s 2.02 p_wen_s 0 p_ref_art_s 0 directive 1 decision 0 codification 0 recast 0 ///
amending 0 council_lr 13.02 council_eu 2.63 days_left 74.91 proposal_backlog 253.73 ///
econ 0 envi 0 imco 0 inta 0 itre 0 libe 0) tvc(p_size_s p_wen_s directive council_eu) ///
texp(ln(_t))

lab var s1 "Low structural complexity"
lab var s2 "High structural complexity"

twoway line s1 s2 _tscurve if _tscurve<1826, scheme(plotplain) lpattern (solid dash) ///
title("Figure 1. Survival functions: structural policy complexity") xtitle("Days after proposal publication") ytitle("Probability of survival") xlabel(0(365)1825)


* Figure 2. Survival functions: linguistic policy complexity

set more off

scurve_tvc, generate (s3) at(p_size_s 0 p_wen_s -2 p_ref_art_s 0 directive 1 decision 0 codification 0 recast 0 ///
amending 0 council_lr 13.02 council_eu 2.63 days_left 74.91 proposal_backlog 253.73 ///
econ 0 envi 0 imco 0 inta 0 itre 0 libe 0) tvc(p_size_s p_wen_s directive council_eu) ///
texp(ln(_t))


scurve_tvc, generate (s4) at(p_size_s 0 p_wen_s 1.29 p_ref_art_s 0 directive 1 decision 0 codification 0 recast 0 ///
amending 0 council_lr 13.02 council_eu 2.63 days_left 74.91 proposal_backlog 253.73 ///
econ 0 envi 0 imco 0 inta 0 itre 0 libe 0) tvc(p_size_s p_wen_s directive council_eu) ///
texp(ln(_t))


lab var s3 "Low linguistic complexity"
lab var s4 "High linguistic complexity"

twoway line s3 s4 _tscurve if _tscurve<1826, scheme(plotplain) lpattern (solid dash) ///
title("Figure 2. Survival functions: linguistic policy complexity") xtitle("Days after proposal publication") ytitle("Probability of survival") xlabel(0(365)1825)


* Figure 3. Survival functions: relational policy complexity

set more off

scurve_tvc, generate (s5) at(p_size_s 0 p_wen_s 0 p_ref_art_s -0.62 directive 1 decision 0 codification 0 recast 0 ///
amending 0 council_lr 13.02 council_eu 2.63 days_left 74.91 proposal_backlog 253.73 ///
econ 0 envi 0 imco 0 inta 0 itre 0 libe 0) tvc(p_size_s p_wen_s directive council_eu) ///
texp(ln(_t))


scurve_tvc, generate (s6) at(p_size_s 0 p_wen_s 0 p_ref_art_s 1.83 directive 1 decision 0 codification 0 recast 0 ///
amending 0 council_lr 13.02 council_eu 2.63 days_left 74.91 proposal_backlog 253.73 ///
econ 0 envi 0 imco 0 inta 0 itre 0 libe 0) tvc(p_size_s p_wen_s directive council_eu) ///
texp(ln(_t))

lab var s5 "Low relational complexity"
lab var s6 "High relational complexity"

twoway line s5 s6 _tscurve if _tscurve<1826, scheme(plotplain) lpattern (solid dash) ///
title("Figure 3. Survival functions: relational policy complexity") xtitle("Days after proposal publication") ytitle("Probability of survival") xlabel(0(365)1825)


* For figure 4: generate variables capturing differences in survival probabilities

gen sdiff1=s2-s1
gen sdiff2=s4-s3
gen sdiff3=s6-s5

lab var sdiff1 "Difference (structural)"
lab var sdiff2 "Difference (linguistic)"
lab var sdiff3 "Difference (relational)"


* Figure 4. Difference in survival: three types of policy complexity

sort _tscurve

twoway line sdiff1 sdiff2 sdiff3 _tscurve if _tscurve<1826, scheme(plotplain) lpattern(solid dash dot) ///
title("Figure 4. Difference in survival: three types of policy complexity") ///
xlabel(0(200)2000) yline(0, lpattern(solid) lcolor(black)) ylab(, nogrid) xlab(, nogrid) ///
xtitle("Days after proposal publication", size(small)) ///
ytitle("{&Delta} Survival probability: 5th/95th Percentile", size(small)) ///
xlabel(0(365)1825) ///
ylabel(-.2(.1).4) ///
leg(order(1 2 3))


***************** 
*Online Appendix* 
*****************


* Table A: Variance inflation factors

set more off

reg tdays p_size_s p_wen_s p_ref_art_s directive decision codification recast ///
amending council_lr council_eu days_left proposal_backlog ///
econ envi imco inta itre libe

vif


* Table B: Grambsch-Therneau Test of proportional hazards assumption

set more off

stcox p_size_s p_wen_s p_ref_art_s directive decision codification recast ///
amending council_lr council_eu days_left proposal_backlog ///
econ envi imco inta itre libe

estat phtest, detail


* Tables C-H: Different combinations of the complexity variables


* Table C: Structural and linguistic policy complexity only

set more off

stcox p_size_s p_wen_s directive decision codification recast ///
amending council_lr council_eu days_left proposal_backlog ///
econ envi imco inta itre libe, tvc(p_size_s p_wen_s directive council_eu) texp(ln(_t))

outreg2 using "TableC", label word eform bdec(3) replace


* Table D: Structural and relational policy complexity only

set more off

stcox p_size_s p_ref_art_s directive decision codification recast ///
amending council_lr council_eu days_left proposal_backlog ///
econ envi imco inta itre libe, tvc(p_size_s directive amending council_eu) texp(ln(_t))

outreg2 using "TableD", label word eform bdec(3) replace


* Table E: Linguistic and relational policy complexity only

set more off

stcox p_wen_s p_ref_art_s directive decision codification recast ///
amending council_lr council_eu days_left proposal_backlog ///
econ envi imco inta itre libe, tvc(p_wen_s directive council_eu) texp(ln(_t))

outreg2 using "TableE", label word eform bdec(3) replace


* Table F: Structrual policy complexity only

set more off

stcox p_size_s directive decision codification recast ///
amending council_lr council_eu days_left proposal_backlog ///
econ envi imco inta itre libe, tvc(p_size_s directive recast amending council_eu) texp(ln(_t))

outreg2 using "TableF", label word eform bdec(3) replace


* Table G: Linguistic policy complexity only

set more off

stcox p_wen_s directive decision codification recast ///
amending council_lr council_eu days_left proposal_backlog ///
econ envi imco inta itre libe, tvc(p_wen_s directive council_eu) texp(ln(_t))

outreg2 using "TableG", label word eform bdec(3) replace


* Table H: Relational policy complexity only

set more off

stcox p_ref_art_s directive decision codification recast ///
amending council_lr council_eu days_left proposal_backlog ///
econ envi imco inta itre libe, tvc(directive amending council_eu itre) texp(ln(_t))

outreg2 using "TableH", label word eform bdec(3)


* Figures A-D: Corresponding to figures 1-4 in the article, but for regulations instead of directives


* Figure A. Survival functions: structural policy complexity (regulations)

set more off

scurve_tvc, generate (s7) at(p_size_s -0.7 p_wen_s 0 p_ref_art_s 0 regulation 1 decision 0 codification 0 recast 0 ///
amending 0 council_lr 13.02 council_eu 2.2 days_left 74.91 proposal_backlog 253.73 ///
econ 0 envi 0 imco 0 inta 0 itre 0 libe 0) tvc(p_size_s p_wen_s regulation council_eu proposal_backlog) ///
texp(ln(_t))


scurve_tvc, generate (s8) at(p_size_s 2.02 p_wen_s 0 p_ref_art_s 0 regulation 1 decision 0 codification 0 recast 0 ///
amending 0 council_lr 13.02 council_eu 2.2 days_left 74.91 proposal_backlog 253.73 ///
econ 0 envi 0 imco 0 inta 0 itre 0 libe 0) tvc(p_size_s p_wen_s regulation council_eu proposal_backlog) ///
texp(ln(_t))

lab var s7 "Low structural complexity"
lab var s8 "High structural complexity"

twoway line s7 s8 _tscurve if _tscurve<1826, scheme(plotplain) lpattern (solid dash) ///
title("Figure A. Survival functions: structural policy complexity (regulations)") xtitle("Days after proposal publication") ytitle("Probability of survival") xlabel(0(365)1825)


* Figure B. Survival functions: linguistic policy complexity (regulations)

set more off

scurve_tvc, generate (s9) at(p_size_s 0 p_wen_s -2 p_ref_art_s 0 regulation 1 decision 0 codification 0 recast 0 ///
amending 0 council_lr 13.02 council_eu 2.2 days_left 74.91 proposal_backlog 253.73 ///
econ 0 envi 0 imco 0 inta 0 itre 0 libe 0) tvc(p_size_s p_wen_s regulation council_eu proposal_backlog) ///
texp(ln(_t))


scurve_tvc, generate (s10) at(p_size_s 0 p_wen_s 1.29 p_ref_art_s 0 regulation 1 decision 0 codification 0 recast 0 ///
amending 0 council_lr 13.02 council_eu 2.2 days_left 74.91 proposal_backlog 253.73 ///
econ 0 envi 0 imco 0 inta 0 itre 0 libe 0) tvc(p_size_s p_wen_s regulation council_eu proposal_backlog) ///
texp(ln(_t))

lab var s9 "Low linguistic complexity"
lab var s10 "High linguistic complexity"

twoway line s9 s10 _tscurve if _tscurve<1826, scheme(plotplain) lpattern (solid dash) ///
title("Figure B. Survival functions: linguistic policy complexity (regulations)") xtitle("Days after proposal publication") ytitle("Probability of survival") xlabel(0(365)1825)


* Figure C. Survival functions: linguistic policy complexity (regulations)

set more off

scurve_tvc, generate (s11) at(p_size_s 0 p_wen_s 0 p_ref_art_s -0.62 regulation 1 decision 0 codification 0 recast 0 ///
amending 0 council_lr 13.02 council_eu 2.2 days_left 74.91 proposal_backlog 253.73 ///
econ 0 envi 0 imco 0 inta 0 itre 0 libe 0) tvc(p_size_s p_wen_s regulation council_eu proposal_backlog) ///
texp(ln(_t))



scurve_tvc, generate (s12) at(p_size_s 0 p_wen_s 0 p_ref_art_s 1.83 regulation 1 decision 0 codification 0 recast 0 ///
amending 0 council_lr 13.02 council_eu 2.2 days_left 74.91 proposal_backlog 253.73 ///
econ 0 envi 0 imco 0 inta 0 itre 0 libe 0) tvc(p_size_s p_wen_s regulation council_eu proposal_backlog) ///
texp(ln(_t))


lab var s11 "Low relational complexity"
lab var s12 "High relational complexity"

twoway line s11 s12 _tscurve if _tscurve<1826, scheme(plotplain) lpattern (solid dash) ///
title("Figure C. Survival functions: relational policy complexity (regulations)") xtitle("Days after proposal publication") ytitle("Probability of survival") xlabel(0(365)1825)


* For figure D

gen sdiff4=s8-s7
gen sdiff5=s10-s9
gen sdiff6=s12-s11

lab var sdiff4 "Difference (structural)"
lab var sdiff5 "Difference (linguistic)"
lab var sdiff6 "Difference (relational)"


* Figure D. Difference in survival: three types of policy complexity (regulations)

sort _tscurve

twoway line sdiff4 sdiff5 sdiff6 _tscurve if _tscurve<1826, scheme(plotplain) lpattern(solid dash dot) ///
title("Figure D. Difference in survival: three types of policy complexity (regulations)") ///
xlabel(0(200)2000) yline(0, lpattern(solid) lcolor(black)) ylab(, nogrid) xlab(, nogrid) ///
xtitle("Days after proposal publication", size(small)) ///
ytitle("{&Delta} Survival probability: 5th/95th Percentile", size(small)) ///
xlabel(0(365)1825) ///
ylabel(-.2(.1).4) ///
leg(order(1 2 3))


log close
